Learn R Programming

ggmotif (version 0.2.1)

motifLocation: Extract and Visualize Motif Information from MEME Software

Description

motifLocation Visualize motif location in a specificial sequences..

Value

Return a plot

Arguments

data

A data frame file from getMotifFromXML function.

tree.path

A file path of the correponding phylogenetic tree. The IDs of the phylogenetic tree must be same as the IDs of sequences used to identify motifs using MEME.

Author

Xiang LI <lixiang117423@foxmail.com>

Examples

Run this code
# without phylogenetic tree
filepath <- system.file("examples", "meme.xml", package = "ggmotif")
motif_extract <- getMotifFromMEME(data = filepath, format="xml")
motif_plot <- motifLocation(data = motif_extract)

# with phylogenetic tree
filepath <- system.file("examples", "meme.xml", package = "ggmotif")
treepath <- system.file("examples", "ara.nwk", package="ggmotif")
motif_extract <- getMotifFromMEME(data = filepath, format="xml")
motif_plot <- motifLocation(data = motif_extract, tree = treepath)

Run the code above in your browser using DataLab